import { View, Button, Form, Text, RadioGroup, Picker, Image, Input, Radio, Label, ScrollView } from '@tarojs/components'
import Taro from '@tarojs/taro';
import { useState } from 'react';
import { addDogInfo } from '../../services/dogAPI';

import './style.less'

export default (props) => {
  const [dogDate, setDogDate] = useState({ petBirthday: '请选择生日', petSex: '请选择性别', petType: '请选择犬种' })
  const [imgUrl, setImgUrl] = useState({ img1: null, immunization: null })


  const onDateChange = (type, value) => {
    switch (type) {
      case 'petSex':
        setDogDate({ ...dogDate, petSex: selector[value] })
        break;
      case 'petBirthday':
        setDogDate({ ...dogDate, petBirthday: value })
        break;
      case 'petType':
        setDogDate({ ...dogDate, petType: dogType[value].text })//value 01  text 文字
        break;
      default:
        break;
    }

  }
  const selector = ['雄', '雌']
  const dogType = [
    {
      value: 0,
      text: '金毛',
    },
    {
      value: 1,
      text: '拉布拉多',
    },

  ]

  const modeList = [
    {
      value: 1,
      text: '邮寄',
    },
    {
      value: 2,
      text: '自取',
    },

  ]

  const addImage = (e) => {
    console.log("🚀 ~ file: index.jsx ~ line 94 ~ addImage ~ e", e)

    if (e == 'img1') {
      Taro.chooseImage({
        count: 1, // 默认9
        sizeType: ['original', 'compressed'], // 可以指定是原图还是压缩图，默认二者都有
        sourceType: ['album', 'camera'], // 可以指定来源是相册还是相机，默认二者都有，在H5浏览器端支持使用 `user` 和 `environment`分别指定为前后摄像头
        success: function (res) {
          // 返回选定照片的本地文件路径列表，tempFilePath可以作为img标签的src属性显示图片
          var tempFilePaths = res.tempFilePaths
          setImgUrl({ ...imgUrl, img1: tempFilePaths[0] })
        },
        fail () {
          Taro.showToast({
            title: '上传失败请重试',
            icon: 'error',
            duration: 1000
          })
        }
      })

    } else {
      Taro.chooseImage({
        count: 1, // 默认9
        sizeType: ['original', 'compressed'], // 可以指定是原图还是压缩图，默认二者都有
        sourceType: ['album', 'camera'], // 可以指定来源是相册还是相机，默认二者都有，在H5浏览器端支持使用 `user` 和 `environment`分别指定为前后摄像头
        success: function (res) {
          // 返回选定照片的本地文件路径列表，tempFilePath可以作为img标签的src属性显示图片
          var tempFilePaths = res.tempFilePaths
          setImgUrl({ ...imgUrl, immunization: tempFilePaths[0] })
        },
        fail () {
          Taro.showToast({
            title: '上传失败请重试',
            icon: 'error',
            duration: 1000
          })
        }
      })
    }

    console.log("🚀 ~ file: index.jsx ~ line 61 ~ addImage ~ tempFilePaths", imgUrl)


  }
  const formSubmit = e => {
    console.log(e)
    const value = e.detail.value
    addDogInfo({ ...value, ...dogDate, ...imgUrl }).then((res) => {
      console.log('dogInfo xinwe', res);
    })
  }

  const formReset = e => {
    console.log(e)
  }
  const rules = [
    {
      name: 'name',
      rules: { required: true, message: '请填写收货人姓名' },
    },
    {
      name: 'telNumber',
      rules: [{ required: true, message: '请填写收货人电话' }, { mobile: true, message: '电话格式不对' }]
    },
  ]
  return (
    <ScrollView scrollY style={{
      height: '100vh'
    }}
    >
      <View class='page' >
        <Form onSubmit={formSubmit} onReset={formReset} >
          <mp-form rules={rules} >
            <mp-cells title=''>
              <mp-cell title='宠物名称' extClass=''>
                <Input name='petName' placeholder='请输入宠养区域' />
              </mp-cell>
              <mp-cell title='宠物性别' extClass=''>
                <Picker name='petSex' mode='selector' range={selector} onChange={(e) => { onDateChange('petSex', e.detail.value) }}>
                  <View className='picker'>
                    {dogDate.petSex}
                  </View>
                </Picker>
              </mp-cell>
              <mp-cell title='犬种' extClass=''>
                <Picker name='petType' mode='selector' range={dogType} rangeKey='text' onChange={(e) => { onDateChange('petType', e.detail.value) }}>
                  <View className='picker'>
                    {dogDate.petType}
                  </View>
                </Picker>
              </mp-cell>
              <mp-cell title='生日' extClass=''>
                <Picker name='petBirthday' mode='date' onChange={(e) => { onDateChange('petBirthday', e.detail.value) }}>
                  <View className='picker'>
                    {dogDate.petBirthday}
                  </View>
                </Picker>
              </mp-cell>
              <mp-cell title='毛色' extClass=''>
                <Input name='petColor' placeholder='请输入宠养区域' />
              </mp-cell>
              <mp-cell title='宠物照片' extClass=''>
                {
                  !imgUrl.img1 ?
                    <View className='addImage' onClick={() => addImage('img1')} >
                      <Text>+</Text>
                    </View>
                    :
                    <Image className='dogImg1' name='img1' src={imgUrl.img1} onClick={() => addImage('img1')} />
                }

              </mp-cell>
              <mp-cell title='免疫证明' extClass=''>
                {
                  !imgUrl.immunization ?
                    <View className='addImage' onClick={() => addImage('immunization')} >
                      <Text>+</Text>
                    </View>
                    :
                    <Image className='dogImg1' name='immunization' src={imgUrl.immunization} onClick={() => addImage('immunization')} />
                }
                {/* <Input name='immunization' placeholder='请输入身份证号' type='idcard' /> */}
              </mp-cell>
              <mp-cell title='详细地址' extClass=''>
                <Input name='address' placeholder='请输入详细地址' />
              </mp-cell>
              <mp-cell title='申领方式' extClass=''>
                <View className='radio-list'>
                  <RadioGroup name='applyMethod'>
                    {modeList.map((item, i) => {
                      return (
                        <Label className='radio-list__label' for={i} key={i}>
                          <Radio color='#FCD905' className='radio-list__radio' value={item.value} >{item.text}</Radio>
                        </Label>
                      )
                    })}
                  </RadioGroup>
                </View>
              </mp-cell>



            </mp-cells>
          </mp-form>
          <View slot='button' style={{ margin: '4em 0 2em 0' }}>
            <Button class='weui-btn' type='primary' loading={false} formType='submit'>确定</Button>
          </View>
        </Form>
      </View>
    </ScrollView >
  )
}




